==> sgad-ERAS-1.0.1-project.tar.bz2: sgad-ERAS-1.0.1/src/sgad-cnf.lua <==
-------------------------------------------------------------------------
-- $Author: fpina $
-- $Revision: 159864 $  - $Date: 2014-12-11 10:01:07 -0200 (Thu, 11 Dec 2014) $
-------------------------------------------------------------------------

-------------------------------------------------------------------------
-- Arquivo de configurao do SGA Daemon
-------------------------------------------------------------------------

SGAD_CONF.platform_mapping.Windows64 = "Windows"

local verbose = require "sga.verbose"
verbose:init("")
verbose:init("** ATENO!!!! -- Usando arquivo de configurao default.       **")
verbose:init("** Este arquivo deve ser copiado para outro diretrio, que      **")
verbose:init("** deve estar definido no arquivo ./sga-daemon (sga-daemon.bat) **")
verbose:init("** em DEFAULT_SGA_CONFIG_DIR.                                   **")
verbose:init("")

-------------------------------------------------------------------------
-- Configurao dos SGAs
-------------------------------------------------------------------------

-- Configurao padro dos ns
Default {
  csbase_platform_id = "No especificada",
  csbase_num_processors = 1,
  csbase_memory_ram_info_mb = 0,
  csbase_memory_swap_info_mb = 0,
  csbase_clock_speed_mhz = 0,
  csbase_file_separator = "/",
  csbase_project_root_directory = "../../_project", --Em relao ao SGA!
  csbase_algorithm_root_directory = "../../algorithms", --Em relao ao SGA!
  csbase_sandbox_root_directory = "/tmp/sandbox",
  csbase_byte_order = BIG_ENDIAN,
  csbase_disabled = NO,
  csbase_benchmarks = NO,
  csbase_net_benchmark = NO,
  csbase_cpu_capacity = NO_CAPACITY,
  csbase_reading_disk_capacity = NO_CAPACITY,
  csbase_writing_disk_capacity = NO_CAPACITY,
  csbase_enable_historic = NO,
  csbase_partition_name = "sda",
  csbase_net_interface_name = "eth0",
  -- csbase_requirements = {},
}

SGA {
  csbase_name = "odin",
  csbase_platform_id = "Linux26g4_64",
  csbase_num_processors = 2,
  csfs = {
       launch_daemon = YES,
       properties = { HOST="10.211.55.3", PORT=10000, ROOT_DIR = "../csfs/root"},
  },
}

SGA {
  csbase_name = "Retina-MacBook-Pro",
  csbase_platform_id = "MacOS109",
  csbase_num_processors = 4,
  loadlib = "testLib",
  -- csfs = {
  --      launch_daemon = YES,
  --      properties = { HOST="192.168.1.12", PORT=10000, ROOT_DIR = "../.."},
  -- },
}

SGA {
  csbase_name = "lfpina",
  csbase_platform_id = "MacOS109",
  csbase_num_processors = 4,
  loadlib = "testLib",
}

==> sgad-ERAS-1.0.5-project.tar.bz2: sgad-ERAS-1.0.5/src/sgad-cnf.lua <==
-------------------------------------------------------------------------
-- $Author: fpina $
-- $Revision: 179623 $  - $Date: 2017-04-20 13:29:37 -0300 (Thu, 20 Apr 2017) $
-------------------------------------------------------------------------

-------------------------------------------------------------------------
-- Arquivo de configurao do SGA Daemon
-------------------------------------------------------------------------

SGAD_CONF.platform_mapping.Windows64 = "Windows"

local verbose = require "sga.verbose"
verbose:init("")
verbose:init("** ATENO!!!! -- Usando arquivo de configurao default.       **")
verbose:init("** Este arquivo deve ser copiado para outro diretrio, que      **")
verbose:init("** deve estar definido no arquivo ./sga-daemon (sga-daemon.bat) **")
verbose:init("** em DEFAULT_SGA_CONFIG_DIR.                                   **")
verbose:init("")

-------------------------------------------------------------------------
-- Configurao dos SGAs
-------------------------------------------------------------------------

-- Configurao padro dos ns
Default {
  csbase_platform_id = "No especificada",
  csbase_num_processors = 1,
  csbase_memory_ram_info_mb = 0,
  csbase_memory_swap_info_mb = 0,
  csbase_clock_speed_mhz = 0,
  csbase_file_separator = "/",
  csbase_project_root_directory = "../../_project", --Em relao ao SGA!
  csbase_algorithm_root_directory = "../../algorithms", --Em relao ao SGA!
  csbase_sandbox_root_directory = "/tmp/sandbox",
  csbase_byte_order = BIG_ENDIAN,
  csbase_disabled = NO,
  csbase_benchmarks = NO,
  csbase_net_benchmark = NO,
  csbase_cpu_capacity = NO_CAPACITY,
  csbase_reading_disk_capacity = NO_CAPACITY,
  csbase_writing_disk_capacity = NO_CAPACITY,
  csbase_enable_historic = NO,
  csbase_partition_name = "sda",
  csbase_net_interface_name = "eth0",
  -- csbase_requirements = {},
}

SGA {
  csbase_sga_name = "odin",
  csbase_platform_id = "Linux26g4_64",
  csbase_num_processors = 2,
  csfs = {
       launch_daemon = YES,
       properties = { HOST="10.211.55.3", PORT=10000, ROOT_DIR = "../csfs/root"},
  },
}

SGA {
  csbase_sga_name = "Retina-MacBook-Pro",
  csbase_platform_id = "MacOS109",
  csbase_num_processors = 4,
  -- loadlib = "testLib",
  -- csfs = {
  --      launch_daemon = YES,
  --      properties = { HOST="192.168.1.12", PORT=10000, ROOT_DIR = "../.."},
  -- },
}

SGA {
  csbase_sga_name = "fpina-w",
  csbase_platform_id = "MacOS109",
  csbase_num_processors = 4,
  -- loadlib = "testLib",
}
